@@ -58,6 +58,7 @@ class InstanceManager:
             pass
     
     def _get_instance_metrics(self):
+        self._timeout_instances()
         metrics = dict()
 
         for key in tuple(self._instances.keys()):
@@ -77,7 +78,8 @@ class InstanceManager:
 
         
     def _get_prometheus_instance_metrics(self):
-        return "# TYPE bptk_instance_count gauge " + str(len(self._instances))
+        self._timeout_instances()
+        return "# HELP bptk_instance_count The number of instances in the beergame server\n# TYPE bptk_instance_count gauge\nbptk_instance_count " + str(len(self._instances))
 
     def create_instance(self,**timeout):
         """
@@ -119,7 +121,6 @@ class InstanceManager:
                 Means that the specified time has already passed, and the session should be terminated.
         """
 
-
         for key in tuple(self._instances.keys()): # we're iterating over a copy of the keys here to ensure we don't delete an element from the dictionary while iterating through it.
             current_time = datetime.datetime.now()
             try:
